@@ -14,10 +14,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1301, USA.
  */
 #include <gtk/gtk.h>
 
+#ifdef HAVE_CONFIG_H
+# include "../gf_config.h"
+#endif
+
+#include "gf_internal.h"
+
 #include <account.h>
 #include <blist.h>
 #include <debug.h>
@@ -40,7 +46,6 @@
 #include "gf_display.h"
 #include "gf_event.h"
 #include "gf_event_info.h"
-#include "gf_internal.h"
 #include "gf_notification.h"
 #include "gf_preferences.h"
 #include "gf_utils.h"
@@ -437,7 +442,15 @@ static void
 gf_action_context_position(GtkMenu *menu, gint *x, gint *y, gboolean pushin,
 						   gpointer data)
 {
-/*	GfDisplay *display = GF_DISPLAY(data);*/
+	GtkRequisition req;
+	gint scrheight = 0;
+
+	scrheight = gdk_screen_get_height(gtk_widget_get_screen(GTK_WIDGET(menu)));
+
+	gtk_widget_size_request(GTK_WIDGET(menu), &req);
+
+	if((*y + req.height > scrheight) && (scrheight - req.height > 0))
+			*y = scrheight - req.height;
 }
 
 static void
