@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1301, USA.
  */
 #ifndef _WIN32
 # include <gdk/gdkx.h>
@@ -30,6 +30,12 @@ typedef HMONITOR WINAPI GF_MonitorFromRect(LPCRECT,DWORD);
 typedef BOOL WINAPI GF_GetMonitorInfo(HMONITOR,LPMONITORINFO);
 #endif /* _WIN32 */
 
+#ifdef HAVE_CONFIG_H
+# include "../gf_config.h"
+#endif
+
+#include "gf_internal.h"
+
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
