@@ -14,11 +14,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1301, USA.
  */
 #include <glib.h>
 #include <string.h>
 
+#ifdef HAVE_CONFIG_H
+# include "../gf_config.h"
+#endif
+
+#include "gf_internal.h"
 #include "gf_utils.h"
 
 gint
